Documentation
¶
Overview ¶
Package closeenvelope provides the encoder for the client message CLOSE which is a request to terminate a subscription.
Index ¶
Constants ¶
const L = "CLOSE"
L is the label associated with this type of codec.Envelope.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type T ¶
type T struct {
ID *subscription.Id
}
T is a CLOSE envelope, which is a signal from client to relay to stop a specified subscription.
func NewFrom ¶
func NewFrom(id *subscription.Id) *T
NewFrom creates a new closeenvelope.T populated with subscription Id.
func Parse ¶
Parse reads a CLOSE envelope from minified JSON into a newly allocated closeenvelope.T.
func (*T) Marshal ¶
Marshal a closeenvelope.T envelope in minified JSON, appending to a provided destination slice.
Click to show internal directories.
Click to hide internal directories.